##  Step 3: Connecting SAP LeanIX to the SAP Build Instance
When you use SAP discovery, SAP LeanIX uses the SAP Build Process Automation API to discover your SAP Build instances. This process is independent of your use of SAP Build Apps or SAP Build Code.
To connect SAP LeanIX to SAP Build, do the following:
  1. In the administration area of SAP LeanIX, go to **Integrations**.
  2. Choose **Add Integration**.
  3. Select **SAP Build** and choose **Configure**.
  4. Provide an integration name and choose **Next**.
  5. Copy and paste the service key in the JSON format generated in the section “Creating an SAP Cloud Management Service Instance and Service Key," and choose **Next**.
  6. Copy and paste the service key in the JSON format generated in “Step 2: Creating an SAP Build Process Automation Instance and Service Key,” and chose **Verify credentials**.
  7. Choose **Finish.**
